@@ -252,7 +252,8 @@ def create_button(
 ):
     button = QPushButton()
     button.setMaximumWidth(360)
-    main_layout = QVBoxLayout(button)
+    main_layout = QVBoxLayout()
+    button.setLayout(main_layout)
     main_layout.setContentsMargins(0, 0, 0, 0)
     label = create_label(
         text = text,
@@ -293,6 +294,10 @@ def create_button(
             color: {font_color};
             font-weight: {font_weight};
             background-color: {background_color};
+            padding-left: {padding_left_value}px;
+            padding-top: {padding_top_value}px;
+            padding-right: {padding_right_value}px;
+            padding-bottom: {padding_bottom_value}px;
             border: {border_width}px solid {border_color};
             border-radius: {border_radius}px;
         }}
